@@ -1,4 +1,4 @@
-from datetime import date, timedelta
+from datetime import date, datetime, timedelta, timezone
 from typing import Iterable, List, Optional
 
 from ..auth import Auth
@@ -88,6 +88,25 @@ class EmsService(ConfiguredApi):
         )
         return UtilityUsage.from_api(resp)
 
+    def get_usage(
+        self,
+        facility_id: int,
+        interval: str,
+        resource_type: ResourceType = ResourceType.ELECTRIC,
+        start: datetime = datetime.now(timezone.utc) - timedelta(days=365),
+        end: datetime = datetime.now(timezone.utc),
+    ) -> UtilityUsage:
+        """Get utility usage for facility `facility_id` and resource `resource_type`"""
+        resp = self.get(
+            f"facilities/{facility_id}/usage/{interval}",
+            params={
+                "type": resource_type.value,
+                "time_start": int(start.timestamp()),
+                "time_end": int(end.timestamp()),
+            },
+        )
+        return UtilityUsage.from_api(resp)
+
     def get_utility_contracts_for_facility(self, facility_id: int) -> Iterable[UtilityContract]:
         return PagedRecords(
             api=self, url=f"facilities/{facility_id}/contracts", record_parser=UtilityContract.from_api
